@@ -14,7 +14,7 @@ logger.setLevel(logging.INFO)
 
 
 
-class OperationsDBConnection:
+class MySQLDbConnection:
     def __init__(self, ssm_db_user: str, ssm_db_pass: str, ssm_db_host: str, ssm_db_name:str,
                  read_timeout=59, write_timeout=59, connection_echo=False,
                  isolation_level="REPEATABLE READ"):
